@@ -133,4 +133,17 @@ class Bioinformatics(object):
             taxonomic_hierarchy = taxonomic_hierarchy,
         )
 
-        return global_chem_bacteria
\ No newline at end of file
+        return global_chem_bacteria
+
+    @staticmethod
+    def initialize_monoclonal_antibody(
+            name = None
+    ):
+
+        from global_chem_extensions.bioinformatics.applications.monoclonal_antibodies import GlobalChemMonoclonalAntibody
+
+        global_chem_monoclonal_antibody = GlobalChemMonoclonalAntibody(
+            name = name
+        )
+
+        return global_chem_monoclonal_antibody
\ No newline at end of file
