@@ -327,6 +327,26 @@ class GlobalChemMolecule(object):
 
         return svg.replace('svg:','')
 
+    def get_curly_smiles(self):
+
+        '''
+
+        Get the CurlySMILES
+
+        '''
+
+        hetereo_atom_types = [i.split()[2] for i in self.cgenff_molecule.atoms if i.split()[2][0] != 'H']
+
+        curly_smiles = self.smiles
+
+        for i, atom in enumerate(curly_smiles):
+
+            if atom.isalpha():
+
+                curly_smiles.replace('%s{%s}' % (atom, hetereo_atom_types[i]))
+
+        return curly_smiles
+
     def get_cgenff_cxsmiles(self):
 
         '''
@@ -345,3 +365,20 @@ class GlobalChemMolecule(object):
 
         return Chem.MolToCXSmiles(self.molecule)
 
+    def get_cgenff_cxsmarts(self):
+
+        '''
+
+        Get the CGenFF CX SMARTS
+
+        '''
+
+        if self.cgenff_molecule:
+
+            hetereo_atom_types = [i.split()[2] for i in self.cgenff_molecule.atoms if i.split()[2][0] != 'H']
+
+            for idx, atom in enumerate(self.molecule.GetAtoms()):
+                atom.SetProp('atom_type', hetereo_atom_types[idx])
+                atom.SetIntProp('atom_idx', idx)
+
+        return Chem.MolToCXSmarts(self.molecule)
\ No newline at end of file
